@@ -2,16 +2,18 @@
 """A daemon to suspend a system on inactivity."""
 
 import argparse
+from collections.abc import Callable, Iterable, Sequence
 import configparser
 from contextlib import suppress
 from datetime import datetime, timedelta, timezone
+from importlib.metadata import version
 import functools
 import logging
 import logging.config
 from pathlib import Path
 import subprocess
 import time
-from typing import Callable, IO, Iterable, List, Optional, Sequence, Tuple, Type, Union
+from typing import IO
 
 import portalocker
 
@@ -25,8 +27,8 @@ _logger = logging.getLogger("autosuspend")
 
 
 def execute_suspend(
-    command: Union[str, Sequence[str]],
-    wakeup_at: Optional[datetime],
+    command: str | Sequence[str],
+    wakeup_at: datetime | None,
 ) -> None:
     """Suspend the system by calling the specified command.
 
@@ -47,9 +49,9 @@ def execute_suspend(
 
 
 def notify_suspend(
-    command_wakeup_template: Optional[str],
-    command_no_wakeup: Optional[str],
-    wakeup_at: Optional[datetime],
+    command_wakeup_template: str | None,
+    command_no_wakeup: str | None,
+    wakeup_at: datetime | None,
 ) -> None:
     """Call a command to notify on suspending.
 
@@ -90,10 +92,10 @@ def notify_suspend(
 
 
 def notify_and_suspend(
-    suspend_cmd: Union[str, Sequence[str]],
-    notify_cmd_wakeup_template: Optional[str],
-    notify_cmd_no_wakeup: Optional[str],
-    wakeup_at: Optional[datetime],
+    suspend_cmd: str | Sequence[str],
+    notify_cmd_wakeup_template: str | None,
+    notify_cmd_no_wakeup: str | None,
+    wakeup_at: datetime | None,
 ) -> None:
     notify_suspend(notify_cmd_wakeup_template, notify_cmd_no_wakeup, wakeup_at)
     execute_suspend(suspend_cmd, wakeup_at)
@@ -112,7 +114,7 @@ def schedule_wakeup(command_template: str, wakeup_at: datetime) -> None:
         )
 
 
-def _safe_execute_activity(check: Activity, logger: logging.Logger) -> Optional[str]:
+def _safe_execute_activity(check: Activity, logger: logging.Logger) -> str | None:
     try:
         return check.check()
     except TemporaryCheckError:
@@ -152,7 +154,7 @@ def execute_checks(
 
 def _safe_execute_wakeup(
     check: Wakeup, timestamp: datetime, logger: logging.Logger
-) -> Optional[datetime]:
+) -> datetime | None:
     try:
         return check.check(timestamp)
     except TemporaryCheckError:
@@ -162,7 +164,7 @@ def _safe_execute_wakeup(
 
 def execute_wakeups(
     wakeups: Iterable[Wakeup], timestamp: datetime, logger: logging.Logger
-) -> Optional[datetime]:
+) -> datetime | None:
     wakeup_at = None
     for wakeup in wakeups:
         this_at = _safe_execute_wakeup(wakeup, timestamp, logger)
@@ -236,7 +238,7 @@ class Processor:
         self._sleep_fn = sleep_fn
         self._wakeup_fn = wakeup_fn
         self._all_activities = all_activities
-        self._idle_since = None  # type: Optional[datetime]
+        self._idle_since = None  # type: datetime | None
 
     def _reset_state(self, reason: str) -> None:
         self._logger.info("%s. Resetting state", reason)
@@ -312,7 +314,7 @@ class Processor:
         self._sleep_fn(wakeup_at)
 
 
-def _continue_looping(run_for: Optional[int], start_time: datetime) -> bool:
+def _continue_looping(run_for: int | None, start_time: datetime) -> bool:
     return (run_for is None) or (
         datetime.now(timezone.utc) < (start_time + timedelta(seconds=run_for))
     )
@@ -346,7 +348,7 @@ def _do_loop_iteration(
 def loop(
     processor: Processor,
     interval: float,
-    run_for: Optional[int],
+    run_for: int | None,
     woke_up_file: Path,
     lock_file: Path,
     lock_timeout: float,
@@ -383,14 +385,14 @@ def config_section_string(section: configparser.SectionProxy) -> str:
 
 def _determine_check_class_and_module(
     class_name: str, internal_module: str
-) -> Tuple[str, str]:
+) -> tuple[str, str]:
     """Determine module and class of a check depending on whether it is internal."""
     if "." in class_name:
         # dot in class name means external class
         import_module, import_class = class_name.rsplit(".", maxsplit=1)
     else:
         # no dot means internal class
-        import_module = "autosuspend.checks.{}".format(internal_module)
+        import_module = f"autosuspend.checks.{internal_module}"
         import_class = class_name
 
     return import_module, import_class
@@ -406,9 +408,9 @@ def _set_up_single_check(
     section: configparser.SectionProxy,
     prefix: str,
     internal_module: str,
-    target_class: Type[CheckType],
+    target_class: type[CheckType],
 ) -> CheckType:
-    name = section.name[len("{}.".format(prefix)) :]
+    name = section.name[len(f"{prefix}.") :]
 
     class_name = _determine_check_class_name(name, section)
 
@@ -430,8 +432,7 @@ def _set_up_single_check(
         )
     except AttributeError as error:
         raise ConfigurationError(
-            "Cannot create built-in check named {}: "
-            "Class does not exist".format(class_name)
+            f"Cannot create built-in check named {class_name}: Class does not exist"
         ) from error
 
     check = klass.create(name, section)
@@ -448,9 +449,9 @@ def set_up_checks(
     config: configparser.ConfigParser,
     prefix: str,
     internal_module: str,
-    target_class: Type[CheckType],
+    target_class: type[CheckType],
     error_none: bool = False,
-) -> List[CheckType]:
+) -> list[CheckType]:
     """Set up :py.class:`Check` instances from a given configuration.
 
     Args:
@@ -469,7 +470,7 @@ def set_up_checks(
     """
     configured_checks = []
 
-    check_section = [s for s in config.sections() if s.startswith("{}.".format(prefix))]
+    check_section = [s for s in config.sections() if s.startswith(f"{prefix}.")]
     for section_name in check_section:
         section = config[section_name]
 
@@ -503,7 +504,7 @@ def parse_config(config_file: Iterable[str]) -> configparser.ConfigParser:
     return config
 
 
-def parse_arguments(args: Optional[Sequence[str]]) -> argparse.Namespace:
+def parse_arguments(args: Sequence[str] | None) -> argparse.Namespace:
     """Parse command line arguments.
 
     Args:
@@ -516,7 +517,7 @@ def parse_arguments(args: Optional[Sequence[str]]) -> argparse.Namespace:
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
 
-    default_config: Optional[IO[str]] = None
+    default_config: IO[str] | None = None
     with suppress(FileNotFoundError, IsADirectoryError, PermissionError):
         # The open file is required after this function finishes inside the argparse
         # result. Therefore, a context manager is not easily usable here.
@@ -553,6 +554,11 @@ def parse_arguments(args: Optional[Sequence[str]]) -> argparse.Namespace:
     subparsers = parser.add_subparsers(title="subcommands", dest="subcommand")
     subparsers.required = True
 
+    parser_version = subparsers.add_parser(
+        "version", help="Outputs the program version"
+    )
+    parser_version.set_defaults(func=main_version)
+
     parser_daemon = subparsers.add_parser(
         "daemon", help="Execute the continuously operating daemon"
     )
@@ -590,7 +596,7 @@ def parse_arguments(args: Optional[Sequence[str]]) -> argparse.Namespace:
     return result
 
 
-def configure_logging(config_file: Optional[IO], debug: bool) -> None:
+def configure_logging(config_file: IO | None, debug: bool) -> None:
     """Configure the python :mod:`logging` system.
 
     Assumes that either a config file is provided, or debugging is enabled.
@@ -687,7 +693,7 @@ def configure_processor(
 
 
 def hook(
-    wakeups: List[Wakeup],
+    wakeups: list[Wakeup],
     wakeup_delta: float,
     wakeup_fn: Callable[[datetime], None],
     woke_up_file: Path,
@@ -736,6 +742,12 @@ def hook(
         )
 
 
+def main_version(
+    args: argparse.Namespace, config: configparser.ConfigParser  # noqa: ARG001
+) -> None:
+    print(version("autosuspend"))  # noqa: T201
+
+
 def main_hook(
     args: argparse.Namespace, config: configparser.ConfigParser  # noqa: ARG001
 ) -> None:
@@ -782,7 +794,7 @@ def main_daemon(args: argparse.Namespace, config: configparser.ConfigParser) ->
     )
 
 
-def main(argv: Optional[Sequence[str]] = None) -> None:
+def main(argv: Sequence[str] | None = None) -> None:
     """Run the daemon."""
     args = parse_arguments(argv)
 
